/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ImageEntity } from './Image';
import { HelpDto, HelpEntity } from "./Help";
export declare class AccountEntity {
    id: string;
    firstName?: string;
    lastName?: string;
    email?: string;
    picture?: ImageEntity;
    userDomain?: string;
    userWidgetDomain: string;
    languageVariant?: string;
    acls?: AclEntity[];
    profileSettings?: ProfileSettingsEntity;
    calendarSettings?: CalendarSettingsEntity;
    directories?: string[];
    help?: HelpEntity;
    accountSettings?: AccountSettingsEntity;
    constructor();
    static fromAccountDto(dto: AccountDto): AccountEntity;
    static fromAccountDto2(dto: AccountDto): AccountEntity;
    static toAccountDto(entity: AccountEntity): AccountDto;
    static toAccountDto2(entity: AccountEntity): AccountDto;
}
export declare class ProfileSettingsEntity {
    locale?: string;
    timeZone?: string;
    country?: string;
    defaultAccount?: string;
    accountName?: string;
    betaNh?: boolean;
    hasSyncModule?: boolean;
    externalLinks?: {
        label: string;
        link: string;
    }[];
    realm?: string;
    hasVisio?: boolean;
}
export declare class CalendarSettingsEntity {
    minTime?: string;
    maxTime?: string;
    eventColor?: string;
    displayDays?: number[];
    eventName?: string;
    slotDuration?: number;
    showBuffer?: boolean;
    privatizeExternal?: boolean;
    defaultView?: string;
}
export declare class AclEntity {
    active: boolean;
    organisationId: string;
    organisation: string;
    organisationName?: string;
    userId: string;
    rightIds?: string[];
}
export declare class AccountSettingsEntity {
    name?: string;
    email?: string;
    logo?: ImageEntity;
    primaryColor?: string;
}
export declare class AccountDto {
    id: string;
    firstName?: string;
    lastName?: string;
    email?: string;
    userDomain?: string;
    userWidgetDomain?: string;
    languageVariant?: string;
    picture?: ImageEntity;
    profileSettings?: {
        country?: string;
        language?: string;
        timeZone?: string;
        defaultAccount?: string;
        accountName?: string;
        betaNh?: boolean;
        hasSyncModule?: boolean;
        externalLinks?: {
            label: string;
            link: string;
        }[];
        realm?: string;
        hasVisio?: boolean;
        preferences?: {
            language?: string;
            timeZone?: string;
            country?: string;
        };
        calendar?: {
            minTime?: string;
            maxTime?: string;
            eventColor?: string;
            displayedDays?: number[];
            eventName?: string;
            slotDuration?: number;
            showBuffer?: boolean;
            privatizeExternal?: boolean;
            defaultView?: string;
        };
    };
    calendarSettings?: {
        minTime?: string;
        maxTime?: string;
        eventColor?: string;
        displayedDays?: number[];
        eventName?: string;
        slotDuration?: number;
        showBuffer?: boolean;
        privatizeExternal?: boolean;
        defaultView?: string;
    };
    acls?: [
        {
            active: boolean;
            organisationId: string;
            organisation: string;
            organisationName?: string;
            userId: string;
            rightIds?: string[];
        }
    ];
    accountSettings?: {
        name?: string;
        email?: string;
        logo?: ImageEntity;
        primaryColor?: string;
    };
    defaultAccount?: string;
    directories?: string[];
    help?: HelpDto;
}
