export declare const FORM_FILE_MAX_SIZE = 10;
export declare const FORM_FILE_EXTENSIONS: string[];
export declare class FormBuilderEntity {
    id: string;
    author: string;
    name: string;
    title: string;
    submitMessage?: string;
    description?: string;
    fields?: FormItemEntity[];
    followUp?: boolean;
    emailNotifications?: boolean;
    emailNotificationsAddresses?: string[];
    clientEmailNotifications?: boolean;
    finalizeLater?: boolean;
    finalizeLaterEmailMessage?: string;
    useAccountConsent?: boolean;
    formResultCount?: number;
    static fromFormBuilderDto(dto: FormBuilderDto): FormBuilderEntity;
    static toFromBuilderDto(entity: FormBuilderEntity): FormBuilderDto;
}
export declare class FormBuilderDto {
    id: string;
    author: string;
    name: string;
    title: string;
    description?: string;
    submitMessage?: string;
    fields?: FormItemDto[];
    followUp?: boolean;
    emailNotifications?: boolean;
    emailNotificationsAddresses?: string[];
    clientEmailNotifications?: boolean;
    finalizeLater?: boolean;
    finalizeLaterEmailMessage?: string;
    useAccountConsent?: boolean;
    formResultCount?: number;
}
export declare class FormValueEntity {
    id: string;
    name?: string;
    value?: any;
    values?: FormValueEntity[];
    static fromCustomFormValueDto(dto: FormValueDto): FormValueEntity;
    static toFormValueDto(entity: FormValueEntity): FormValueDto;
}
export declare class WidgetFormEntity {
    id: string;
    fields?: FormItemEntity[];
    contactFields?: FormItemEntity[];
    uniqueForCompany?: boolean;
    static fromDto(dto: WidgetFormDto): WidgetFormEntity;
}
export declare class WidgetFormDto {
    id: string;
    pages?: {
        fields: FormItemDto[];
    }[];
    uniqueForCompany?: boolean;
}
export declare class FormItemEntity {
    id: string;
    label?: string;
    type: string;
    inputType?: string;
    visible?: boolean;
    disabled?: boolean;
    required?: boolean;
    values?: FormValueEntity[];
    subItem?: FormItemEntity[];
    valueGroups?: FormValueEntity[];
    formatType?: 'none' | 'numeric' | 'alphanumeric' | 'regex';
    pattern?: string;
    minlength?: number;
    maxlength?: number;
    externalId?: string;
    help?: string;
    placeholder?: string;
    otherValue?: boolean;
    category?: boolean;
    readonly?: boolean;
    value?: any;
    fileName?: string;
    multiple?: boolean;
    bind?: string;
    bindGroup?: string;
    static fromFormDto(dto: FormItemDto): FormItemEntity;
    static fromWidgetFormItemDto(dto: WidgetFormItemDto): FormItemEntity;
    static toFormDto(entity: FormItemEntity): FormItemDto;
    static formItemToFormField(field: FormItemEntity, showInvisible: boolean): {
        id: string;
        inputType: string;
        label: string | undefined;
        mandatory: boolean | undefined;
        visible: boolean;
        values: {
            label: string;
            value: string;
            values?: {
                label: string;
                value: string;
            }[] | undefined;
        }[] | undefined;
        bind: string | undefined;
        multiple: boolean | undefined;
        value: any;
        pattern: string | undefined;
        disabled: boolean | undefined;
        minlength: number | undefined;
        maxlength: number | undefined;
    };
    static formItemsToFormFields(formItems: FormItemEntity[], extractSubItem?: boolean, showInvisible?: boolean): any[] | undefined;
}
export declare class FormEntity extends FormItemEntity {
}
export declare class FormItemDto {
    id: string;
    label?: string;
    title?: string;
    type: string;
    inputType?: string;
    visible?: boolean;
    disabled?: boolean;
    mandatory?: boolean;
    values?: FormValueDto[];
    subItem?: FormItemDto[];
    valueGroups?: FormValueDto[];
    valueFormat?: {
        type?: 'none' | 'numeric' | 'alphanumeric' | 'regex';
        valueFormat?: 'none' | 'numeric' | 'alphanumeric' | 'regex';
        minLength?: number;
        maxLength?: number;
        regexType?: string;
        regexValue?: string;
    };
    minlength?: number;
    maxlength?: number;
    pattern?: string;
    externalId?: string;
    help?: string;
    placeholder?: string;
    otherValue?: boolean;
    category?: boolean;
    readonly?: boolean;
    value?: any;
    fileName?: string;
    multiple?: boolean;
    bind?: string;
    bindGroup?: string;
}
export declare class WidgetFormItemDto {
    id: string;
    label?: string;
    title?: string;
    type: string;
    inputType?: string;
    visible?: boolean;
    disabled?: boolean;
    placeholder?: string;
    help?: string;
    externalId?: string;
    required?: boolean;
    values?: FormValueDto[];
    pattern?: string;
    minlength?: number;
    maxlength?: number;
    readonly?: boolean;
    value?: any;
    fileName?: string;
    multiple?: boolean;
    bind?: string;
    bindGroup?: string;
}
export declare class FormValueDto {
    id: string;
    name?: string;
    value?: string;
    values?: FormValueDto[];
}
