/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export declare enum GlobalRight {
    owner = 0,
    accountAdministrator = 1,
    accountAnalytics = 2,
    chatAdministrator = 3,
    chatOperator = 4,
    schedulingAdministrator = 5,
    schedulingStaff = 6,
    testimonialsAdministrator = 7,
    testimonialsModeration = 8,
    accountBilling = 9,
    accountButtons = 10,
    accountEmails = 11,
    accountCalls = 12,
    accountForms = 13,
    accountCRM = 14,
    accountSchedulingAdministrator = 15,
    accountSchedulingSchedule = 16,
    accountSchedulingRead = 17,
    queue = 18,
    schedulingRead = 19,
    accountDataOfficer = 20,
    accountWorkflows = 21,
    accountWorkingPlanning = 22,
    schedulingTeamManager = 23
}
export declare class RightsEntity {
    id: string;
    object?: RightObject;
    scheduling?: SchedulingRight;
    settings?: SettingsRight;
    report?: ReportRight;
    queue?: QueueRight;
    form?: FormRight;
    client?: ClientRight;
    workflow?: WorkflowRight;
    workingPlanning?: WorkingPlanningRight;
    planning?: PlanningRight;
    conference?: ConferenceRight;
    whiteLabel?: WhiteLabelRight;
    static fromRightsDto(dto: RightsDto): RightsEntity;
}
export interface RightObject {
    type: 'company';
    id: string;
}
export interface SchedulingRight {
    appointment: string;
    staffAppointment: string;
}
export interface SettingsRight {
    company: string;
    service: string;
    staff: string;
    resource: string;
    staffCustomPeriod: string;
    process: string;
    widget: string;
    notifications: string;
    payments: string;
    messages: string;
    calendars: string;
    crm: string;
}
export interface ReportRight {
    report: string;
}
export interface QueueRight {
    queue: string;
}
export interface FormRight {
    form: string;
}
export interface ClientRight {
    client: string;
}
export interface WorkflowRight {
    workflow: string;
}
export interface WorkingPlanningRight {
    workingPlanning: string;
}
export interface PlanningRight {
    planning: string;
}
export interface ConferenceRight {
    conference: string;
}
export interface WhiteLabelRight {
    name: string;
    logo: string;
    favicon: string;
}
export declare class RightsDto {
    id: string;
    object?: RightObject;
    scheduling?: SchedulingRight;
    settings?: SettingsRight;
    report?: ReportRight;
    queue?: QueueRight;
    form?: FormRight;
    client?: ClientRight;
    workflow?: WorkflowRight;
    workingPlanning?: WorkingPlanningRight;
    planning?: PlanningRight;
    conference?: ConferenceRight;
    whiteLabel?: WhiteLabelRight;
}
