import { ImageEntity } from "../Image";
import { FormItemDto, FormItemEntity } from "../Form";
export declare class ConferenceLocationEntity {
    type?: "address" | "custom" | "link" | "schedulingCompanyAddress";
    street?: string;
    additionalStreet?: string;
    zipCode?: string;
    country?: string;
    city?: string;
    state?: string;
    link?: string;
    title?: string;
    text?: string;
    geolocation?: {
        lat: number;
        lng: number;
    };
    companyId?: string;
    static fromConferenceLocationDto(dto: ConferenceLocationDto): ConferenceLocationEntity;
    static toConferenceDto(entity: ConferenceLocationEntity): ConferenceLocationDto;
}
export declare class ConferenceTagEntity {
    id?: string;
    tag: string;
    numberOfConferences?: number;
    constructor();
    static fromConferenceTagDto(dto: ConferenceTagDto): ConferenceTagEntity;
    static toConferenceTagDto(entity: ConferenceTagEntity): ConferenceTagDto;
}
export declare class ConferenceSubscriptionRulesEntity {
    allowAdditionalSeats?: boolean;
    numberOfAdditionalSeats?: number;
    waitingList?: boolean;
    static fromSubscriptionRulesDto(dto: SubscriptionRulesDto): ConferenceSubscriptionRulesEntity;
    static toSubscriptionRulesDto(entity: ConferenceSubscriptionRulesEntity): SubscriptionRulesDto;
}
export declare class ConferenceSessionEntity {
    id: string;
    cipherId?: string;
    start: Date;
    status: "opened" | "closed";
    numberOfRegistrations: number;
    numberOfRegisteredSeats: number;
    waitingList?: {
        numberOfRegistrations: number;
        numberOfRegisteredSeats: number;
    };
    conferenceId: string;
    static fromDto(dto: ConferenceSessionDto, conferenceId: string): ConferenceSessionEntity;
    static fromSearchEntity(searchEntity: ConferenceSessionSearchEntity): ConferenceSessionEntity;
    static toDto(entity: ConferenceSessionEntity, timeZone?: string): ConferenceSessionDto;
}
export declare class ConferenceClientEntity {
    id: string;
    firstName: string;
    lastName: string;
    emailAddress?: string;
    phoneNumber?: string;
    static fromDto(dto: ConferenceClientDto): ConferenceClientEntity;
    static toDto(entity: ConferenceClientEntity): ConferenceClientDto;
}
export declare class ConferenceRegistrationEntity {
    id: string;
    cipherId?: string;
    seats: number;
    registered: Date;
    client?: ConferenceClientEntity;
    session: ConferenceSessionEntity;
    form?: FormItemEntity[];
    status: 'accepted' | 'cancelled' | 'waitingList';
    cancelReason?: string;
    static fromDto(dto: ConferenceRegistrationDto, conferenceId: string): ConferenceRegistrationEntity;
    static toDto(entity: ConferenceRegistrationEntity, timeZone?: string): ConferenceRegistrationDto;
}
export declare class ConferenceEntity {
    id?: string;
    cipherId?: string;
    externalId?: string;
    name?: string;
    title?: string;
    description?: string;
    company?: {
        id?: string;
        name?: string;
    };
    code?: string;
    picture?: ImageEntity;
    capacity?: number;
    duration?: number;
    availability?: "public" | "private";
    location?: ConferenceLocationEntity;
    form?: ConferenceFormEntity;
    tags?: ConferenceTagEntity[];
    sessions?: ConferenceSessionEntity[];
    registrationRules?: ConferenceSubscriptionRulesEntity;
    static fromConferenceDto(dto: ConferenceDto): ConferenceEntity;
    static toConferenceDto(entity: ConferenceEntity, timeZone?: string): ConferenceDto;
}
export declare class ConferenceSpeakerEntity {
    id: string;
    userId: string;
    conferenceId: string;
    emailAddress: string;
    firstName?: string;
    lastName?: string;
    static fromDto(dto: ConferenceSpeakerDto, conferenceId: string): ConferenceSpeakerEntity;
    static toDto(entity: ConferenceSpeakerEntity): ConferenceSpeakerDto;
}
export declare class ConferenceInviteeEntity {
    id: string;
    conferenceId: string;
    firstName: string;
    lastName: string;
    emailAddress?: string;
    phoneNumber?: string;
    status: ConferenceInviteeStatus;
    static fromDto(dto: ConferenceInviteeDto, conferenceId: string): ConferenceInviteeEntity;
    static toDto(entity: ConferenceInviteeEntity): ConferenceInviteeDto;
}
export declare class ConferenceFormEntity {
    id?: string;
    name?: string;
    additionalFields?: FormItemEntity[][];
    contactFields: FormItemEntity[];
    static toDto(entity: ConferenceFormEntity): ConferenceFormDto;
    static fromDto(dto: ConferenceFormDto): ConferenceFormEntity;
}
export declare class ConferenceRegistrationCancelEntity {
    reason?: string;
    source?: string;
    static toDto(entity: ConferenceRegistrationCancelEntity): ConferenceRegistrationCancelDto;
}
export declare class ConferenceSessionsSearchBodyEntity {
    startDate: Date;
    endDate?: Date;
    pageNumber?: number;
    timeZone?: string;
    maxResults?: number;
}
export declare class ConferenceSessionsSearchEntity {
    items: ConferenceSessionSearchEntity[];
    totalItems: number;
    static fromDto(dto: ConferenceSessionsSearchDto): ConferenceSessionsSearchEntity;
}
export declare class ConferenceSessionSearchEntity {
    id: string;
    start: Date;
    status: "opened" | "closed";
    numberOfRegistrations: number;
    numberOfRegisteredSeats: number;
    cipherId?: string;
    conference: {
        title: string;
        id: string;
        capacity: number;
        duration: number;
        locationType: "UNKNOWN" | "companyAddress" | "schedulingCompanyAddress" | "link" | "address" | "custom";
        availability: 'public' | 'private';
        numberOfSpeakers: number;
        numberOfInvitees: number;
        tags: ConferenceTagEntity[];
        cipherId?: string;
    };
    static fromDto(dto: ConferenceSessionSearchDto): ConferenceSessionSearchEntity;
}
export declare class ConferenceRegistrationDto {
    id: string;
    cipherId?: string;
    seats: number;
    registered: {
        dateTime: string;
        timeZone?: string;
    };
    client?: ConferenceClientDto;
    session: ConferenceSessionDto;
    form?: FormItemDto[];
    status: 'accepted' | 'cancelled' | 'waitingList';
    cancelReason?: string;
}
export declare class ConferenceClientDto {
    id: string;
    firstName: string;
    lastName: string;
    emailAddress?: string;
    phoneNumber?: string;
}
export declare class ConferenceSessionDto {
    id: string;
    cipherId?: string;
    start: {
        dateTime: string;
        timeZone?: string;
    };
    status: "opened" | "closed";
    numberOfRegistrations: number;
    numberOfRegisteredSeats: number;
    waitingList?: {
        numberOfRegistrations: number;
        numberOfRegisteredSeats: number;
    };
}
export declare class ConferenceSessionSearchDto {
    id: string;
    start: {
        dateTime: string;
        timeZone?: string;
    };
    status: "opened" | "closed";
    numberOfRegistrations: number;
    numberOfRegisteredSeats: number;
    cipherId?: string;
    conference: {
        title: string;
        id: string;
        capacity: number;
        duration: number;
        locationType: "UNKNOWN" | "companyAddress" | "schedulingCompanyAddress" | "link" | "address" | "custom";
        availability: 'public' | 'private';
        numberOfSpeakers: number;
        numberOfInvitees: number;
        tags?: ConferenceTagDto[];
        cipherId?: string;
    };
}
export declare class ConferenceSessionsSearchDto {
    items: ConferenceSessionSearchDto[];
    totalCount: number;
    countPerPage: number;
}
export declare class ConferenceLocationDto {
    type?: "address" | "custom" | "link" | "schedulingCompanyAddress";
    street?: string;
    additionalStreet?: string;
    zipCode?: string;
    country?: string;
    city?: string;
    state?: string;
    link?: string;
    title?: string;
    text?: string;
    geolocation?: {
        lat: number;
        lng: number;
    };
    companyId?: string;
}
export declare class ConferenceTagDto {
    id?: string;
    text?: string;
    numberOfConferences?: number;
}
export declare class SubscriptionRulesDto {
    allowAdditionalSeats?: boolean;
    numberOfAdditionalSeats?: number;
    waitingList?: boolean;
}
export declare class ConferenceFormDto {
    id?: string;
    name?: string;
    additionalFields?: FormItemDto[][];
    contactFields: FormItemDto[];
}
export declare class ConferenceDto {
    id?: string;
    cipherId?: string;
    externalId?: string;
    title?: string;
    description?: string;
    company?: {
        id?: string;
        name?: string;
    };
    code?: string;
    picture?: ImageEntity;
    capacity?: number;
    duration?: number;
    availability?: "public" | "private";
    location?: ConferenceLocationDto;
    form?: ConferenceFormDto;
    sessions?: ConferenceSessionDto[];
    tags?: {
        id?: string;
        name?: string;
    }[];
    registrationRules?: SubscriptionRulesDto;
}
export declare class ConferenceSpeakerDto {
    id: string;
    userId: string;
    emailAddress: string;
    firstName?: string;
    lastName?: string;
}
export declare class ConferenceInviteeDto {
    id: string;
    firstName: string;
    lastName: string;
    emailAddress?: string;
    phoneNumber?: string;
    status: ConferenceInviteeStatus;
}
export declare type ConferenceInviteeStatus = "accepted";
export declare class ConferenceRegistrationCancelDto {
    reason?: string;
    source?: string;
}
