/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { QUERY_RESULT, Repository } from './index';
import { AccountEntity, Logger } from '../index';
import { AuthenticationService } from "../service/authenticationService";
interface Args {
    account?: string;
    crossAccount?: boolean;
    v2_3?: boolean;
}
export declare class AccountRepository extends Repository<AccountEntity, Args> {
    private accountService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    dispose(): void;
    getAccount(bearer: string, account?: string, crossAccount?: boolean): Promise<QUERY_RESULT<AccountEntity>>;
    updateAccount(bearer: string, account: AccountEntity, v2_3?: boolean): Promise<AccountEntity>;
    updatePassword(bearer: string, currentPassword: string, newPassword: string): Promise<void>;
    protected remoteList(bearer: string, args: Args): Promise<AccountEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<AccountEntity>;
    protected remoteCreate(bearer: string, args: Args, item: AccountEntity): Promise<AccountEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: AccountEntity): Promise<AccountEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<AccountEntity[]>;
    protected localGet(args: Args): Promise<AccountEntity>;
    protected localBulkSave(args: Args, staffs: AccountEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: AccountEntity[]): Promise<void>;
}
export {};
