/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { QUERY_RESULTS, Repository } from './index';
import { ActivityEntity, Logger } from '../index';
import { AuthenticationService } from "../service/authenticationService";
interface Args {
    account: string;
    clientId?: string;
    eventId?: string;
}
export declare class ActivityRepository extends Repository<ActivityEntity, Args> {
    private activityService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getAllActivities(bearer: string, account: string, clientId: string): Promise<QUERY_RESULTS<ActivityEntity>>;
    getAllEventActivities(bearer: string, account: string, clientId: string, eventId: string): Promise<QUERY_RESULTS<ActivityEntity>>;
    protected remoteList(bearer: string, args: Args): Promise<ActivityEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<ActivityEntity>;
    protected remoteCreate(bearer: string, args: Args, item: ActivityEntity): Promise<ActivityEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: ActivityEntity): Promise<ActivityEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<ActivityEntity[]>;
    protected localGet(args: Args): Promise<ActivityEntity>;
    protected localBulkSave(args: Args, activities: ActivityEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: ActivityEntity[]): Promise<void>;
    private checkNullable;
}
export {};
