import { IndexedDb } from '../db';
import { EMITTER_TYPE, QUERY_TYPE, Repository } from "./index";
import { CalendarEntity, Logger } from '../index';
import { AuthenticationService } from "../service/authenticationService";
import { PubSubService } from "type-pubsub";
interface Args {
    start?: Date;
    end?: Date;
    timeZone?: string;
    userIdList?: string[];
    anonymousUserIdList?: string[];
    calendarId?: string;
    account: string;
}
export declare class CalendarRepository extends Repository<CalendarEntity, Args> {
    private calendarDb;
    private calendarService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getCalendars(bearer: string, account: string, start: Date, end: Date, timeZone?: string, userIdList?: string[], anonymousUserIdList?: string[], mode?: QUERY_TYPE): Promise<import("./index").QUERY_RESULTS<CalendarEntity>>;
    protected remoteList(bearer: string, args: Args): Promise<CalendarEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<CalendarEntity>;
    protected remoteCreate(bearer: string, args: Args, item: CalendarEntity): Promise<CalendarEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: CalendarEntity): Promise<CalendarEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<CalendarEntity[]>;
    protected localBulkSave(args: Args, calendars: CalendarEntity[]): Promise<void>;
    protected localGet(args: Args): Promise<CalendarEntity>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: CalendarEntity[]): Promise<void>;
    protected onCascadeDelete(data: any, message: EMITTER_TYPE, channel: PubSubService<EMITTER_TYPE>, handler: any): Promise<void>;
}
export {};
