/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { Logger, QUERY_TYPE } from '../index';
import { QUERY_RESULT, QUERY_RESULTS, Repository } from './index';
import { AuthenticationService } from "../service/authenticationService";
import { ConferenceInviteeEntity } from "../data/conference/Conference";
interface Args {
    account: string;
    conferenceId?: string;
    inviteeId?: string;
}
export declare class ConferenceInviteeRepository extends Repository<ConferenceInviteeEntity, Args> {
    private conferenceInviteeDb;
    private conferenceInviteeService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    createConferenceInvitee(bearer: string, account: string, conferenceId: string, speaker: ConferenceInviteeEntity): Promise<ConferenceInviteeEntity>;
    updateConferenceInvitee(bearer: string, account: string, conferenceId: string, inviteeId: string, speaker: ConferenceInviteeEntity): Promise<ConferenceInviteeEntity>;
    deleteConferenceInvitee(bearer: string, account: string, conferenceId: string, inviteeId: string): Promise<void>;
    getConferenceInvitee(bearer: string, account: string, conferenceId: string, inviteeId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<ConferenceInviteeEntity>>;
    getConferenceInvitees(bearer: string, account: string, conferenceId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<ConferenceInviteeEntity>>;
    protected remoteList(bearer: string, args: Args): Promise<ConferenceInviteeEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<ConferenceInviteeEntity>;
    protected remoteCreate(bearer: string, args: Args, item: ConferenceInviteeEntity): Promise<ConferenceInviteeEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: ConferenceInviteeEntity): Promise<ConferenceInviteeEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<ConferenceInviteeEntity[]>;
    protected localGet(args: Args): Promise<ConferenceInviteeEntity>;
    protected localBulkSave(args: Args, items: ConferenceInviteeEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: ConferenceInviteeEntity[]): Promise<void>;
    private checkNullable;
}
export {};
