import { QUERY_RESULTS, QUERY_TYPE, Repository } from "./index";
import { ConferenceRegistrationCancelEntity, ConferenceRegistrationEntity } from "../data/conference/Conference";
import { AuthenticationService } from "../service/authenticationService";
import { IndexedDb } from "../db";
import { Logger } from "../utils/logger";
interface Args {
    account: string;
    conferenceId?: string;
    sessionId?: string;
    registrationId?: string;
    withCancel?: boolean;
    cancelEntity?: ConferenceRegistrationCancelEntity;
}
export declare class ConferenceRegistrationRepository extends Repository<ConferenceRegistrationEntity, Args> {
    private conferenceRegistrationDb;
    private conferenceRegistrationService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getConferenceRegistrationBySession(bearer: string, account: string, conferenceId: string, sessionId: string, withCancel?: boolean, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<ConferenceRegistrationEntity>>;
    generateConferenceRegistrationExportCsv(bearer: string, account: string, options: {
        conferenceId?: string;
        sessionId?: string;
        locale?: string;
    }): Promise<string>;
    updateRegistration(bearer: string, account: string, conferenceId: string, sessionId: string, registration: ConferenceRegistrationEntity): Promise<ConferenceRegistrationEntity>;
    cancelRegistration(bearer: string, account: string, conferenceId: string, sessionId: string, registrationId: string, cancelEntity?: ConferenceRegistrationCancelEntity): Promise<void>;
    protected localBulkDelete(items: ConferenceRegistrationEntity[]): Promise<void>;
    protected localBulkSave(args: Args, items: ConferenceRegistrationEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localGet(args: Args): Promise<ConferenceRegistrationEntity>;
    protected localList(args: Args): Promise<ConferenceRegistrationEntity[]>;
    protected remoteCreate(bearer: string, args: Args, item: ConferenceRegistrationEntity): Promise<ConferenceRegistrationEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected remoteGet(bearer: string, args: Args): Promise<ConferenceRegistrationEntity>;
    protected remoteList(bearer: string, args: Args): Promise<ConferenceRegistrationEntity[]>;
    protected remoteUpdate(bearer: string, args: Args, item: ConferenceRegistrationEntity): Promise<ConferenceRegistrationEntity>;
    private checkNullable;
}
export {};
