/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { ConferenceEntity, Logger, QUERY_TYPE } from '../index';
import { EMITTER_TYPE, QUERY_RESULT, QUERY_RESULTS, Repository } from './index';
import { AuthenticationService } from "../service/authenticationService";
import { PubSubService } from "type-pubsub";
interface Args {
    account: string;
    conferenceId?: string;
    timeZone?: string;
}
export declare class ConferenceRepository extends Repository<ConferenceEntity, Args> {
    private conferenceDb;
    private conferenceService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    createConference(bearer: string, account: string, conference: ConferenceEntity, timeZone?: string): Promise<ConferenceEntity>;
    updateConference(bearer: string, account: string, conferenceId: string, conference: ConferenceEntity, timeZone?: string): Promise<ConferenceEntity>;
    deleteConference(bearer: string, account: string, conferenceId: string): Promise<void>;
    getConference(bearer: string, account: string, conferenceId: string, timeZone?: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<ConferenceEntity>>;
    getConferences(bearer: string, account: string, timeZone?: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<ConferenceEntity>>;
    protected remoteList(bearer: string, args: Args): Promise<ConferenceEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<ConferenceEntity>;
    protected remoteCreate(bearer: string, args: Args, item: ConferenceEntity): Promise<ConferenceEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: ConferenceEntity): Promise<ConferenceEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<ConferenceEntity[]>;
    protected localGet(args: Args): Promise<ConferenceEntity>;
    protected localBulkSave(args: Args, items: ConferenceEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: ConferenceEntity[]): Promise<void>;
    private checkNullable;
    protected onWatch(data: any, message: EMITTER_TYPE, channel: PubSubService<EMITTER_TYPE>, handler: any): Promise<void>;
    private updateConferenceSession;
}
export {};
