/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { Logger, QUERY_TYPE } from '../index';
import { QUERY_RESULT, QUERY_RESULTS, Repository } from './index';
import { AuthenticationService } from "../service/authenticationService";
import { ConferenceSessionEntity, ConferenceSessionsSearchBodyEntity, ConferenceSessionsSearchEntity } from "../data/conference/Conference";
interface Args {
    account: string;
    conferenceId?: string;
    sessionId?: string;
    timeZone?: string;
}
export declare class ConferenceSessionRepository extends Repository<ConferenceSessionEntity, Args> {
    private conferenceSessionDb;
    private conferenceSessionService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    createConferenceSession(bearer: string, account: string, conferenceId: string, timeZone: string, session: ConferenceSessionEntity): Promise<ConferenceSessionEntity>;
    updateConferenceSession(bearer: string, account: string, conferenceId: string, sessionId: string, session: ConferenceSessionEntity): Promise<ConferenceSessionEntity>;
    deleteConferenceSession(bearer: string, account: string, conferenceId: string, sessionId: string): Promise<void>;
    getConferenceSession(bearer: string, account: string, conferenceId: string, sessionId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<ConferenceSessionEntity>>;
    getConferenceSessions(bearer: string, account: string, conferenceId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<ConferenceSessionEntity>>;
    searchConferenceSessions(bearer: string, account: string, searchBody: ConferenceSessionsSearchBodyEntity): Promise<ConferenceSessionsSearchEntity>;
    protected remoteList(bearer: string, args: Args): Promise<ConferenceSessionEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<ConferenceSessionEntity>;
    protected remoteCreate(bearer: string, args: Args, item: ConferenceSessionEntity): Promise<ConferenceSessionEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: ConferenceSessionEntity): Promise<ConferenceSessionEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<ConferenceSessionEntity[]>;
    protected localGet(args: Args): Promise<ConferenceSessionEntity>;
    protected localBulkSave(args: Args, items: ConferenceSessionEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: ConferenceSessionEntity[]): Promise<void>;
    private checkNullable;
}
export {};
