/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { Logger, QUERY_TYPE } from '../index';
import { QUERY_RESULT, QUERY_RESULTS, Repository } from './index';
import { AuthenticationService } from "../service/authenticationService";
import { ConferenceSpeakerEntity } from "../data/conference/Conference";
import { BatchService } from "../service/batchService";
interface Args {
    account: string;
    conferenceId?: string;
    speakerId?: string;
}
export declare class ConferenceSpeakerRepository extends Repository<ConferenceSpeakerEntity, Args> {
    private conferenceSpeakerDb;
    private conferenceSpeakerService;
    private batchService;
    constructor(authenticationService: AuthenticationService, batchService: BatchService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    createConferenceSpeaker(bearer: string, account: string, conferenceId: string, speaker: ConferenceSpeakerEntity): Promise<ConferenceSpeakerEntity>;
    addConferenceSpeakers(bearer: string, account: string, conferenceId: string, speakers: ConferenceSpeakerEntity[]): Promise<ConferenceSpeakerEntity[]>;
    updateConferenceSpeaker(bearer: string, account: string, conferenceId: string, speakerId: string, speaker: ConferenceSpeakerEntity): Promise<ConferenceSpeakerEntity>;
    deleteConferenceSpeaker(bearer: string, account: string, conferenceId: string, speakerId: string): Promise<void>;
    getConferenceSpeaker(bearer: string, account: string, conferenceId: string, speakerId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<ConferenceSpeakerEntity>>;
    getConferenceSpeakers(bearer: string, account: string, conferenceId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<ConferenceSpeakerEntity>>;
    protected remoteList(bearer: string, args: Args): Promise<ConferenceSpeakerEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<ConferenceSpeakerEntity>;
    protected remoteCreate(bearer: string, args: Args, item: ConferenceSpeakerEntity): Promise<ConferenceSpeakerEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: ConferenceSpeakerEntity): Promise<ConferenceSpeakerEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<ConferenceSpeakerEntity[]>;
    protected localGet(args: Args): Promise<ConferenceSpeakerEntity>;
    protected localBulkSave(args: Args, items: ConferenceSpeakerEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: ConferenceSpeakerEntity[]): Promise<void>;
    private checkNullable;
}
export {};
