import { IndexedDb } from '../db';
import { ContactEntity, Logger, QUERY_TYPE } from '../index';
import { EMITTER_TYPE, QUERY_PAGINATED_RESULT, QUERY_RESULT, QUERY_RESULTS, Repository } from './index';
import { ContactAdvancedSearchEntity } from '../data/Contact';
import { AuthenticationService } from "../service/authenticationService";
import { PubSubService } from "type-pubsub";
interface Args {
    account: string;
    contactId?: string;
    query?: string;
    showAnonymized?: boolean;
    sort?: string;
    maxResult?: number;
}
export declare class ContactRepository extends Repository<ContactEntity, Args> {
    private contactDb;
    private contactService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    protected onCascadeChange(data: any, message: EMITTER_TYPE, channel: PubSubService<EMITTER_TYPE>, handler: any): Promise<void>;
    searchContacts(bearer: string, account: string | undefined, query: string, showAnonymized?: boolean, sort?: string, maxResult?: number): Promise<QUERY_RESULTS<ContactEntity>>;
    searchContactWithPages(bearer: string, account: string | undefined, query: string | ContactAdvancedSearchEntity, showAnonymized?: boolean, sort?: string, pageToken?: string): Promise<QUERY_PAGINATED_RESULT<ContactEntity>>;
    createContact(bearer: string, account: string, contact: ContactEntity): Promise<ContactEntity>;
    updateContact(bearer: string, account: string, contactId: string, contact: ContactEntity): Promise<ContactEntity>;
    deleteContact(bearer: string, account: string, contactId: string): Promise<void>;
    getContact(bearer: string, account: string, contactId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<ContactEntity>>;
    protected remoteList(bearer: string, args: Args): Promise<ContactEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<ContactEntity>;
    protected remoteCreate(bearer: string, args: Args, item: ContactEntity): Promise<ContactEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: ContactEntity): Promise<ContactEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<ContactEntity[]>;
    protected localGet(args: Args): Promise<ContactEntity>;
    protected localBulkSave(args: Args, contacts: ContactEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: ContactEntity[]): Promise<void>;
    private checkNullable;
}
export {};
