import { QUERY_RESULT, QUERY_RESULTS, QUERY_TYPE, Repository } from "./index";
import { CustomStatusEntity } from "../data/CustomStatus";
import { AuthenticationService } from "../service/authenticationService";
import { IndexedDb } from "../db";
import { Logger } from "../utils/logger";
interface Args {
    account: string;
    customStatusId?: string;
    appointmentId?: string;
}
export declare class CustomStatusRepository extends Repository<CustomStatusEntity, Args> {
    private customStatusDb;
    private customStatusService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getAllCustomStatus(bearer: string, account: string, appointmentId?: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<CustomStatusEntity>>;
    getCustomStatus(bearer: string, account: string, customStatusId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<CustomStatusEntity>>;
    createCustomStatus(bearer: string, account: string, customStatus: CustomStatusEntity): Promise<CustomStatusEntity>;
    updateCustomStatus(bearer: string, account: string, customStatusId: string, customStatus: CustomStatusEntity): Promise<CustomStatusEntity>;
    deleteCustomStatus(bearer: string, account: string, customStatusId: string): Promise<void>;
    protected remoteGet(bearer: string, args: Args): Promise<CustomStatusEntity>;
    protected remoteList(bearer: string, args: Args): Promise<CustomStatusEntity[]>;
    protected remoteCreate(bearer: string, args: Args, item: CustomStatusEntity): Promise<CustomStatusEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: CustomStatusEntity): Promise<CustomStatusEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<CustomStatusEntity[]>;
    protected localGet(args: Args): Promise<CustomStatusEntity>;
    protected localBulkSave(args: Args, items: CustomStatusEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: CustomStatusEntity[]): Promise<void>;
    private checkNullable;
}
export {};
