import { IndexedDb } from '../db';
import { EMITTER_TYPE, QUERY_RESULT, QUERY_RESULTS, QUERY_TYPE, Repository } from './index';
import { EventEntity } from '../data/Event';
import { AuthenticationService } from "../service/authenticationService";
import { PubSubService } from "type-pubsub";
import { Logger } from "../utils/logger";
import { EventFields } from "../service/items/EventFields";
import { CustomStatusEntity } from "../data/CustomStatus";
import { EventSearchBodyEntity, EventSearchEntity, EventSearchOption, EventSearchPageEntity } from "../data/EventSearch";
import { BatchService } from "../service/batchService";
interface Args {
    account?: string;
    companyId?: string;
    eventId?: string;
    timeZone?: string;
    force?: boolean;
    userIds?: string;
    showPersonal?: boolean;
    showDeleted?: boolean;
    start?: Date;
    end?: Date;
    fields?: EventFields[];
    syncToken?: string;
}
export declare class EventRepository extends Repository<EventEntity, Args> {
    REPOSITORY_NAME: string;
    private eventDb;
    private eventService;
    private batchService;
    private eventMetaStorage;
    constructor(authenticationService: AuthenticationService, batchService: BatchService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    dispose(): void;
    protected onCascadeDelete(data: any, message: EMITTER_TYPE, channel: PubSubService<EMITTER_TYPE>, handler: any): Promise<void>;
    createEvent(bearer: string, account: string, companyId: string, event: EventEntity, timeZone: string, force: boolean): Promise<EventEntity>;
    updateEvent(bearer: string, account: string, companyId: string, event: EventEntity, timeZone?: string, force?: boolean): Promise<EventEntity>;
    getEvent(bearer: string, organisationEmail: string, eventId: string, showPersonal?: boolean, mode?: QUERY_TYPE): Promise<QUERY_RESULT<EventEntity>>;
    getCompanyEvent(bearer: string, organisationEmail: string, companyId: string, eventId: string, showPersonal?: boolean): Promise<EventEntity>;
    getAllEvents(bearer: string, organisationEmail: string, userIds: string[], start: Date, end: Date, showPersonal?: boolean, showDeleted?: boolean, timeZone?: string, fields?: EventFields[], syncToken?: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<EventEntity>>;
    getEventWithCoverage(bearer: string, organisationEmail: string, userIds: string[], start: Date, end: Date, showPersonal?: boolean, showDeleted?: boolean, timeZone?: string, fields?: EventFields[], mode?: QUERY_TYPE): Promise<QUERY_RESULTS<EventEntity>>;
    searchEvents(bearer: string, organisationEmail: string, searchBody: EventSearchBodyEntity, options?: EventSearchOption): Promise<EventSearchPageEntity>;
    countAppointmentConflict(bearer: string, organisationEmail: string, searchBody: EventSearchBodyEntity): Promise<number>;
    deleteAppointmentConflict(bearer: string, organisationEmail: string, eventId: string): Promise<void>;
    updateEventStatus(bearer: string, account: string, companyId: string, eventId: string, status: string): Promise<EventEntity>;
    updateEventsToStatus(bearer: string, account: string, events: EventSearchEntity[], status: string | CustomStatusEntity): Promise<EventEntity[]>;
    updateEventCustomStatus(bearer: string, account: string, companyId: string, eventId: string, customStatus: CustomStatusEntity): Promise<EventEntity>;
    getExternalEvent(bearer: string, organisationEmail: string, userIds: string[], start: Date, end: Date, timeZone?: string): Promise<EventEntity[]>;
    deleteAllEvents(): Promise<void>;
    protected remoteList(bearer: string, args: Args): Promise<EventEntity[]>;
    protected remoteSyncList(bearer: string, args: Args): Promise<{
        nextSyncToken?: string;
        results: EventEntity[];
    }>;
    protected remoteGet(bearer: string, args: Args): Promise<EventEntity>;
    protected remoteCreate(bearer: string, args: Args, item: EventEntity): Promise<EventEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: EventEntity): Promise<EventEntity>;
    protected remoteUpdateStatus(bearer: string, args: Args, status: string): Promise<EventEntity>;
    protected remoteUpdateCustomStatus(bearer: string, args: Args, customStatus: CustomStatusEntity): Promise<EventEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<EventEntity[]>;
    protected localGet(args: Args): Promise<EventEntity>;
    protected localBulkSave(args: Args, events: EventEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: EventEntity[]): Promise<void>;
    private _syncListRemoteFirstThenLocal;
}
export {};
