import { IndexedDb } from '../db';
import { EMITTER_TYPE, QUERY_RESULT, QUERY_RESULTS, QUERY_TYPE, Repository } from './index';
import { EventEntity } from '../data/Event';
import { AuthenticationService } from "../service/authenticationService";
import { Logger } from "../utils/logger";
import { PubSubService } from "type-pubsub";
interface Args {
    account?: string;
    eventId?: string;
    timeZone?: string;
    userIds?: string[];
    start?: Date;
    end?: Date;
}
export declare class ExternalEventRepository extends Repository<EventEntity, Args> {
    REPOSITORY_NAME: string;
    private externalEventDb;
    private eventService;
    private eventMetaStorage;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    dispose(): void;
    protected onCascadeDelete(data: any, message: EMITTER_TYPE, channel: PubSubService<EMITTER_TYPE>, handler: any): Promise<void>;
    getEvent(bearer: string, organisationEmail: string, eventId: string, timeZone?: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<EventEntity>>;
    getEvents(bearer: string, organisationEmail: string, userIds: string[], start: Date, end: Date, timeZone?: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<EventEntity>>;
    getIcs(bearer: string, icsUrl: string): Promise<any>;
    deleteLocalExternalEvents(): Promise<void>;
    protected remoteList(bearer: string, args: Args): Promise<EventEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<EventEntity>;
    protected remoteCreate(bearer: string, args: Args, item: EventEntity): Promise<EventEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: EventEntity): Promise<EventEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<EventEntity[]>;
    protected localGet(args: Args): Promise<EventEntity>;
    protected localBulkSave(args: Args, events: EventEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: EventEntity[]): Promise<void>;
    private localDeleteByUser;
}
export {};
