import { QUERY_RESULT, QUERY_RESULTS, QUERY_TYPE, Repository } from "./index";
import { FormResultEntity } from "../data/FormResult";
import { AuthenticationService } from "../service/authenticationService";
import { IndexedDb } from "../db";
import { Logger } from "../utils/logger";
interface Args {
    account?: string;
    formId?: string;
    resultId?: string;
    timeZone?: string;
}
export declare class FormResultRepository extends Repository<FormResultEntity, Args> {
    private formResultService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getAllResultByForm(bearer: string, formId: string, timeZone: string, account: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<FormResultEntity>>;
    getResultById(bearer: string, formId: string, resultId: string, timeZone: string, account: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<FormResultEntity>>;
    updateResultById(bearer: string, formId: string, resultId: string, result: FormResultEntity, timeZone: string, account: string): Promise<FormResultEntity>;
    deleteResultById(bearer: string, formId: string, resultId: string, account: string): Promise<void>;
    protected localBulkDelete(items: FormResultEntity[]): Promise<void>;
    protected localBulkSave(args: Args, items: FormResultEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localGet(args: Args): Promise<FormResultEntity>;
    protected localList(args: Args): Promise<FormResultEntity[]>;
    protected remoteCreate(bearer: string, args: Args, item: FormResultEntity): Promise<FormResultEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected remoteGet(bearer: string, args: Args): Promise<FormResultEntity>;
    protected remoteList(bearer: string, args: Args): Promise<FormResultEntity[]>;
    protected remoteUpdate(bearer: string, args: Args, item: FormResultEntity): Promise<FormResultEntity>;
    private checkNullable;
}
export {};
