/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { QUERY_RESULT, Repository } from "./index";
import { AuthenticationService } from "../service/authenticationService";
import { FreeSlotEntity } from "../data/FreeSlot";
import { Logger } from "../utils/logger";
interface Args {
    account?: string;
    companyId?: string;
    start?: string;
    end?: string;
    serviceId?: string;
    staffId?: string;
    timeZone?: string;
    iterationCount?: string;
}
export declare class FreeSlotRepository extends Repository<FreeSlotEntity, Args> {
    private indexedDb;
    private freeSlotService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getFreeSlots(bearer: string, account: string, companyId: string, startDate: string, endDate: string, serviceId: string, staffId?: string, timeZone?: string, iterationCount?: string): Promise<QUERY_RESULT<FreeSlotEntity>>;
    protected remoteList(bearer: string, args: any): Promise<FreeSlotEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<FreeSlotEntity>;
    protected remoteCreate(bearer: string, args: Args, item: FreeSlotEntity): Promise<FreeSlotEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: FreeSlotEntity): Promise<FreeSlotEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localBulkSave(args: Args, items: FreeSlotEntity[]): Promise<void>;
    protected localGet(args: Args): Promise<FreeSlotEntity>;
    protected localList(args: Args): Promise<FreeSlotEntity[]>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: FreeSlotEntity[]): Promise<void>;
}
export {};
