/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { QUERY_RESULT, Repository } from './index';
import { NotificationStatusEntity } from "../data/NotificationStatus";
import { Logger } from "../utils/logger";
interface Args {
    userId?: string;
}
export declare class NotificationStatusRepository extends Repository<NotificationStatusEntity, Args> {
    private notificationStatusDb;
    constructor(indexedDb: IndexedDb, logger?: Logger);
    refreshesNotificationStatus(bearer: string, userId: string, readDate: Date): Promise<NotificationStatusEntity>;
    getNotificationStatus(bearer: string, userId: string): Promise<QUERY_RESULT<NotificationStatusEntity>>;
    localClear(): Promise<void>;
    protected localGet(args: Args): Promise<NotificationStatusEntity>;
    protected localBulkSave(args: Args, items: NotificationStatusEntity[]): Promise<void>;
    protected localList(args: Args): Promise<NotificationStatusEntity[]>;
    protected localBulkDelete(items: NotificationStatusEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected remoteList(bearer: string, args: Args): Promise<NotificationStatusEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<NotificationStatusEntity>;
    protected remoteCreate(bearer: string, args: Args, item: NotificationStatusEntity): Promise<NotificationStatusEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: NotificationStatusEntity): Promise<NotificationStatusEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
}
export {};
