/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { QUERY_RESULT, QUERY_RESULTS, QUERY_TYPE, Repository } from './index';
import { Logger } from '../index';
import { AuthenticationService } from "../service/authenticationService";
import { PlanningEntity } from "../data/planning/Planning";
interface Args {
    account: string;
    planningId?: string;
}
export declare class PlanningRepository extends Repository<PlanningEntity, Args> {
    private planningDb;
    private planningService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getAllPlannings(bearer: string, account: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<PlanningEntity>>;
    getPlanning(bearer: string, account: string, planningId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<PlanningEntity>>;
    createPlanning(bearer: string, account: string, planning: PlanningEntity): Promise<PlanningEntity>;
    updatePlanning(bearer: string, account: string, planningId: string, planning: PlanningEntity): Promise<PlanningEntity>;
    deletePlanning(bearer: string, account: string, planningId: string): Promise<void>;
    protected remoteList(bearer: string, args: Args): Promise<PlanningEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<PlanningEntity>;
    protected remoteCreate(bearer: string, args: Args, item: PlanningEntity): Promise<PlanningEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: PlanningEntity): Promise<PlanningEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<PlanningEntity[]>;
    protected localGet(args: Args): Promise<PlanningEntity>;
    protected localBulkSave(args: Args, items: PlanningEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: PlanningEntity[]): Promise<void>;
    private checkNullable;
}
export {};
