/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { QUERY_RESULT, QUERY_TYPE, Repository } from './index';
import { PrivacyPolicyEntity } from "../data/PrivacyPolicy";
import { AuthenticationService } from "../service/authenticationService";
import { Logger } from "../utils/logger";
interface Args {
    ownerId: string;
    ownerLogin: string;
}
export declare class PrivacyPolicyRepository extends Repository<PrivacyPolicyEntity, Args> {
    private privacyPolicyDb;
    private privacyPolicyService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getPrivacyPolicy(bearer: string, ownerId: string, ownerLogin: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<PrivacyPolicyEntity>>;
    protected remoteList(bearer: string, args: Args): Promise<PrivacyPolicyEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<PrivacyPolicyEntity>;
    protected remoteCreate(bearer: string, args: Args, item: PrivacyPolicyEntity): Promise<PrivacyPolicyEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: PrivacyPolicyEntity): Promise<PrivacyPolicyEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localGet(args: Args): Promise<PrivacyPolicyEntity>;
    protected localBulkSave(args: Args, items: PrivacyPolicyEntity[]): Promise<void>;
    protected localList(args: Args): Promise<PrivacyPolicyEntity[]>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: PrivacyPolicyEntity[]): Promise<void>;
}
export {};
