/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { Logger } from '../index';
import { QUERY_RESULTS, Repository } from './index';
import { AuthenticationService } from "../service/authenticationService";
import { QueueRegistrationEntity, QueueRegistrationStatus } from "../data/QueueRegistration";
interface Args {
    account?: string;
    queueId?: string;
    registrationId?: string;
    status?: QueueRegistrationStatus;
}
export declare class QueueRegistrationRepository extends Repository<QueueRegistrationEntity, Args> {
    private queueRegistrationsService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getAllQueueRegistrations(bearer: string, account: string, queueId: string, status?: QueueRegistrationStatus): Promise<QUERY_RESULTS<QueueRegistrationEntity>>;
    updateQueueRegistration(bearer: string, account: string, queueId: string, registrationId: string, queueRegistration: QueueRegistrationEntity): Promise<QueueRegistrationEntity>;
    nextQueueRegistration(bearer: string, account: string, queueId: string): Promise<QueueRegistrationEntity | undefined>;
    protected remoteList(bearer: string, args: Args): Promise<QueueRegistrationEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<QueueRegistrationEntity>;
    protected remoteCreate(bearer: string, args: Args, item: QueueRegistrationEntity): Promise<QueueRegistrationEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: QueueRegistrationEntity): Promise<QueueRegistrationEntity>;
    remoteNext(bearer: string, args: Args): Promise<QueueRegistrationEntity | undefined>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(): Promise<QueueRegistrationEntity[]>;
    protected localGet(args: Args): Promise<QueueRegistrationEntity>;
    protected localBulkSave(args: Args, companies: QueueRegistrationEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: QueueRegistrationEntity[]): Promise<void>;
    private checkNullable;
}
export {};
