/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { QUERY_RESULT, QUERY_RESULTS, QUERY_TYPE, Repository } from "./index";
import { AuthenticationService } from "../service/authenticationService";
import { QueueEntity } from "../data/Queue";
import { Logger } from "../utils/logger";
interface Args {
    queueId?: string;
    account: string;
}
export declare class QueueRepository extends Repository<QueueEntity, Args> {
    private queueDb;
    private queueService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getAllQueues(account: string, bearer: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<QueueEntity>>;
    getQueue(bearer: string, queueId: string, account: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<QueueEntity>>;
    createQueue(bearer: string, account: string, queue: QueueEntity): Promise<QueueEntity>;
    updateQueue(bearer: string, account: string, queueId: string, queue: QueueEntity): Promise<QueueEntity>;
    deleteQueue(bearer: string, queueId: string, account: string, mode?: QUERY_TYPE): Promise<void>;
    protected remoteList(bearer: string, args: Args): Promise<QueueEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<QueueEntity>;
    protected remoteCreate(bearer: string, args: Args, item: QueueEntity): Promise<QueueEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected remoteUpdate(bearer: string, args: Args, item: QueueEntity): Promise<QueueEntity>;
    protected localList(args: Args): Promise<QueueEntity[]>;
    protected localBulkSave(args: Args, items: QueueEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: QueueEntity[]): Promise<void>;
    protected localGet(args: Args): Promise<QueueEntity>;
    private checkNullable;
}
export {};
