/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { QUERY_TYPE, Repository } from "./index";
import { AuthenticationService } from "../service/authenticationService";
import { Logger } from "../utils/logger";
import { ReportDashboardFilter, ReportsEntity } from "../data/Reporting";
interface Args {
    account: string;
    locale?: string;
    filters?: ReportDashboardFilter;
}
export declare class ReportingRepository extends Repository<ReportsEntity, Args> {
    private reportingService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getReports(bearer: string, account: string, locale?: string, filters?: ReportDashboardFilter, mode?: QUERY_TYPE): Promise<import("./index").QUERY_RESULT<ReportsEntity>>;
    protected remoteList(bearer: string, args: Args): Promise<ReportsEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<ReportsEntity>;
    protected remoteCreate(bearer: string, args: Args, item: ReportsEntity): Promise<ReportsEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: ReportsEntity): Promise<ReportsEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<ReportsEntity[]>;
    protected localGet(args: Args): Promise<ReportsEntity>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: ReportsEntity[]): Promise<void>;
    protected localBulkSave(args: Args, items: ReportsEntity[]): Promise<void>;
    private checkNullable;
}
export {};
