/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { Repository } from "./index";
import { RightsEntity } from "../data/Rights";
import { AuthenticationService } from "../service/authenticationService";
import { Logger } from "../utils/logger";
interface Args {
    rightsId?: string[];
    organisation?: string;
}
export declare class RightsRepository extends Repository<RightsEntity, Args> {
    private rightsService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getRights(bearer: string, organisation: string, rightsId: string[]): Promise<RightsEntity[]>;
    protected remoteList(bearer: string, args: Args): Promise<RightsEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<RightsEntity>;
    protected remoteCreate(bearer: string, args: Args, item: RightsEntity): Promise<RightsEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: RightsEntity): Promise<RightsEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<RightsEntity[]>;
    protected localGet(args: Args): Promise<RightsEntity>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: RightsEntity[]): Promise<void>;
    protected localBulkSave(args: Args, items: RightsEntity[]): Promise<void>;
}
export {};
