/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { EMITTER_TYPE, QUERY_RESULT, QUERY_RESULTS, QUERY_TYPE, Repository } from './index';
import { AuthenticationService } from "../service/authenticationService";
import { ServiceGroupEntity } from "../data/ServiceGroup";
import { PubSubService } from "type-pubsub";
import { Logger } from "../utils/logger";
interface Args {
    account: string;
    companyId: string;
    serviceGroupId?: string;
}
export declare class ServiceGroupRepository extends Repository<ServiceGroupEntity, Args> {
    private readonly serviceGroupDb;
    private serviceGroupService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    dispose(): void;
    protected onCascadeDelete(data: any, message: EMITTER_TYPE, channel: PubSubService<EMITTER_TYPE>, handler: any): Promise<void>;
    getAllServiceGroups(bearer: string, account: string, companyId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<ServiceGroupEntity>>;
    getServiceGroup(bearer: string, account: string, companyId: string, serviceGroupId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<ServiceGroupEntity>>;
    createServiceGroup(bearer: string, account: string, companyId: string, serviceGroup: ServiceGroupEntity): Promise<ServiceGroupEntity>;
    updateServiceGroup(bearer: string, account: string, companyId: string, serviceGroupId: string, serviceGroup: ServiceGroupEntity): Promise<ServiceGroupEntity>;
    deleteServiceGroup(bearer: string, account: string, companyId: string, serviceGroupId: string): Promise<void>;
    protected remoteList(bearer: string, args: Args): Promise<ServiceGroupEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<ServiceGroupEntity>;
    protected remoteCreate(bearer: string, args: Args, item: ServiceGroupEntity): Promise<ServiceGroupEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: ServiceGroupEntity): Promise<ServiceGroupEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<ServiceGroupEntity[]>;
    protected localGet(args: Args): Promise<ServiceGroupEntity>;
    protected localBulkSave(args: Args, items: ServiceGroupEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: ServiceGroupEntity[]): Promise<void>;
    private checkNullable;
}
export {};
