import { IndexedDb } from '../db';
import { EMITTER_TYPE, QUERY_RESULT, QUERY_RESULTS, QUERY_TYPE, Repository } from './index';
import { Logger, ServiceEntity } from '../index';
import { AuthenticationService } from "../service/authenticationService";
import { PubSubService } from "type-pubsub";
interface Args {
    account: string;
    companyId: string;
    serviceId?: string;
}
export declare class ServiceRepository extends Repository<ServiceEntity, Args> {
    private serviceDb;
    private serviceService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    dispose(): void;
    protected onCascadeDelete(data: any, message: EMITTER_TYPE, channel: PubSubService<EMITTER_TYPE>, handler: any): Promise<void>;
    getAllServices(bearer: string, account: string, companyId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<ServiceEntity>>;
    getService(bearer: string, account: string, companyId: string, serviceId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<ServiceEntity>>;
    createService(bearer: string, account: string, companyId: string, service: ServiceEntity): Promise<ServiceEntity>;
    updateService(bearer: string, account: string, companyId: string, serviceId: string, service: ServiceEntity): Promise<ServiceEntity>;
    deleteService(bearer: string, account: string, companyId: string, serviceId: string): Promise<void>;
    protected remoteList(bearer: string, args: Args): Promise<ServiceEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<ServiceEntity>;
    protected remoteCreate(bearer: string, args: Args, item: ServiceEntity): Promise<ServiceEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: ServiceEntity): Promise<ServiceEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<ServiceEntity[]>;
    protected localGet(args: Args): Promise<ServiceEntity>;
    protected localBulkSave(args: Args, items: ServiceEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: ServiceEntity[]): Promise<void>;
    private checkNullable;
}
export {};
