/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { EMITTER_TYPE, QUERY_RESULT, QUERY_RESULTS, QUERY_TYPE, Repository } from './index';
import { Logger } from '../index';
import { AuthenticationService } from "../service/authenticationService";
import { PubSubService } from "type-pubsub";
import { ServiceResourceEntity } from "../data/ServiceResource";
interface Args {
    account: string;
    companyId: string;
    serviceResourceId?: string;
}
export declare class ServiceResourceRepository extends Repository<ServiceResourceEntity, Args> {
    private serviceResourceDb;
    private serviceResourceService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    dispose(): void;
    protected onCascadeDelete(data: any, message: EMITTER_TYPE, channel: PubSubService<EMITTER_TYPE>, handler: any): Promise<void>;
    getAllServiceResources(bearer: string, account: string, companyId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<ServiceResourceEntity>>;
    getServiceResource(bearer: string, account: string, companyId: string, serviceResourceId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<ServiceResourceEntity>>;
    createServiceResource(bearer: string, account: string, companyId: string, resource: ServiceResourceEntity): Promise<ServiceResourceEntity>;
    updateServiceResource(bearer: string, account: string, companyId: string, serviceResourceId: string, resource: ServiceResourceEntity): Promise<ServiceResourceEntity>;
    deleteServiceResource(bearer: string, account: string, companyId: string, serviceResourceId: string): Promise<void>;
    protected remoteList(bearer: string, args: Args): Promise<ServiceResourceEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<ServiceResourceEntity>;
    protected remoteCreate(bearer: string, args: Args, item: ServiceResourceEntity): Promise<ServiceResourceEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: ServiceResourceEntity): Promise<ServiceResourceEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<ServiceResourceEntity[]>;
    protected localGet(args: Args): Promise<ServiceResourceEntity>;
    protected localBulkSave(args: Args, items: ServiceResourceEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: ServiceResourceEntity[]): Promise<void>;
    private checkNullable;
}
export {};
