/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IndexedDb } from '../db';
import { EMITTER_TYPE, QUERY_RESULT, QUERY_RESULTS, QUERY_TYPE, Repository } from './index';
import { AuthenticationService } from "../service/authenticationService";
import { StaffGroupEntity } from "../data/StaffGroup";
import { PubSubService } from "type-pubsub";
import { Logger } from "../utils/logger";
interface Args {
    account: string;
    companyId: string;
    staffGroupId?: string;
}
export declare class StaffGroupRepository extends Repository<StaffGroupEntity, Args> {
    private staffGroupDb;
    private staffGroupService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    dispose(): void;
    protected onCascadeDelete(data: any, message: EMITTER_TYPE, channel: PubSubService<EMITTER_TYPE>, handler: any): Promise<void>;
    getAllStaffGroups(bearer: string, account: string, companyId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<StaffGroupEntity>>;
    getStaffGroup(bearer: string, account: string, companyId: string, staffGroupId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<StaffGroupEntity>>;
    createStaffGroup(bearer: string, account: string, companyId: string, staffGroup: StaffGroupEntity): Promise<StaffGroupEntity>;
    updateStaffGroup(bearer: string, account: string, companyId: string, staffGroupId: string, staffGroup: StaffGroupEntity): Promise<StaffGroupEntity>;
    deleteStaffGroup(bearer: string, account: string, companyId: string, staffGroupId: string): Promise<void>;
    protected remoteList(bearer: string, args: Args): Promise<StaffGroupEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<StaffGroupEntity>;
    protected remoteCreate(bearer: string, args: Args, item: StaffGroupEntity): Promise<StaffGroupEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: StaffGroupEntity): Promise<StaffGroupEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<StaffGroupEntity[]>;
    protected localGet(args: Args): Promise<StaffGroupEntity>;
    protected localBulkSave(args: Args, items: StaffGroupEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: StaffGroupEntity[]): Promise<void>;
    private checkNullable;
}
export {};
