import { IndexedDb } from '../db';
import { EMITTER_TYPE, QUERY_RESULT, QUERY_RESULTS, QUERY_TYPE, Repository } from './index';
import { Logger, SettingsWorkingDayEntity, StaffEntity } from '../index';
import { AuthenticationService } from "../service/authenticationService";
import { PubSubService } from "type-pubsub";
interface Args {
    account: string;
    companyId: string;
    staffId?: string;
}
export declare class StaffRepository extends Repository<StaffEntity, Args> {
    private staffDb;
    private staffService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    dispose(): void;
    protected onCascadeDelete(data: any, message: EMITTER_TYPE, channel: PubSubService<EMITTER_TYPE>, handler: any): Promise<void>;
    getAllStaffs(bearer: string, account: string, companyId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<StaffEntity>>;
    getStaff(bearer: string, account: string, companyId: string, staffId: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<StaffEntity>>;
    createStaff(bearer: string, account: string, companyId: string, staff: StaffEntity): Promise<StaffEntity>;
    updateStaff(bearer: string, account: string, companyId: string, staffId: string, staff: StaffEntity): Promise<StaffEntity>;
    patchAllStaff(bearer: string, account: string, companyId: string, workingHours?: SettingsWorkingDayEntity[], vacations?: {
        startDate?: Date;
        endDate?: Date;
    }[], staffIds?: string[]): Promise<QUERY_RESULTS<StaffEntity>>;
    deleteStaff(bearer: string, account: string, companyId: string, staffId: string): Promise<void>;
    protected remoteList(bearer: string, args: Args): Promise<StaffEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<StaffEntity>;
    protected remoteCreate(bearer: string, args: Args, item: StaffEntity): Promise<StaffEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: StaffEntity): Promise<StaffEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<StaffEntity[]>;
    protected localGet(args: Args): Promise<StaffEntity>;
    protected localBulkSave(args: Args, staffs: StaffEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: StaffEntity[]): Promise<void>;
    private checkNullable;
}
export {};
