/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { UserService } from '../service/userService';
import { UserDb } from "../db/userDb";
import { IndexedDb } from '../db';
import { EMITTER_TYPE, QUERY_RESULT, QUERY_RESULTS, QUERY_TYPE, Repository } from './index';
import { CalendarTeamEntity, Logger, UserEntity } from '../index';
import { AuthenticationService } from "../service/authenticationService";
import { PubSubService } from "type-pubsub";
import { CalendarTeamDb } from "../db/calendarTeamDb";
interface Args {
    userId?: string;
    organisation?: string;
    defaultUsers?: boolean;
}
export declare abstract class UserAbstractRepository extends Repository<UserEntity, Args> {
    protected userDb: UserDb;
    protected teamDb: CalendarTeamDb;
    protected userService: UserService;
    protected constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger, repositoryName?: string);
    protected abstract initUserDb(indexedDb: IndexedDb): UserDb;
    protected abstract initTeamDb(indexedDb: IndexedDb): CalendarTeamDb;
    abstract getAllUsers(bearer: string, organisation?: string, mode?: QUERY_TYPE): Promise<QUERY_RESULTS<UserEntity>>;
    getAllTeams(bearer: string, organisation?: string): Promise<QUERY_RESULTS<CalendarTeamEntity>>;
    getUser(bearer: string, userId: string, organisation?: string, mode?: QUERY_TYPE): Promise<QUERY_RESULT<UserEntity>>;
    protected remoteList(bearer: string, args: Args): Promise<UserEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<UserEntity>;
    protected remoteCreate(bearer: string, args: Args, item: UserEntity): Promise<UserEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: UserEntity): Promise<UserEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<UserEntity[]>;
    protected localGet(args: Args): Promise<UserEntity>;
    protected localBulkSave(args: Args, items: UserEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: UserEntity[]): Promise<void>;
    private checkNullable;
    dispose(): void;
    protected onCascadeDelete(data: any, message: EMITTER_TYPE, channel: PubSubService<EMITTER_TYPE>, handler: any): Promise<void>;
}
export {};
