/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { QUERY_TYPE, Repository } from "./index";
import { AuthenticationService } from "../service/authenticationService";
import { IndexedDb } from "../db";
import { Logger } from "../utils/logger";
import { UserEntity } from "../data/User";
interface Args {
    account: string;
    userId?: string;
}
export declare class UserDirectoryRepository extends Repository<UserEntity, Args> {
    private userDirectoryDb;
    private userDirectoryService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getAllUsersOfDirectory(bearer: string, account: string, mode?: QUERY_TYPE): Promise<import("./index").QUERY_RESULTS<UserEntity>>;
    protected remoteGet(bearer: string, args: Args): Promise<UserEntity>;
    protected remoteList(bearer: string, args: Args): Promise<UserEntity[]>;
    protected remoteCreate(bearer: string, args: Args, item: UserEntity): Promise<UserEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: UserEntity): Promise<UserEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<UserEntity[]>;
    protected localGet(args: Args): Promise<UserEntity>;
    protected localBulkSave(args: Args, items: UserEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: UserEntity[]): Promise<void>;
}
export {};
