/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { WidgetFormFieldsAPIProperties } from '../service/widgetFormService';
import { IndexedDb } from '../db/index';
import { Repository } from './index';
import { AuthenticationService } from "../service/authenticationService";
import { WidgetFormEntity } from "../data/Form";
import { Logger } from "../utils/logger";
interface Args {
    account: string;
    companyId?: string;
    serviceId?: string;
    formId?: string;
    properties?: WidgetFormFieldsAPIProperties;
}
export declare class WidgetFormRepository extends Repository<WidgetFormEntity, Args> {
    private widgetFormDb;
    private widgetFormService;
    constructor(authenticationService: AuthenticationService, indexedDb: IndexedDb, baseURL: string, logger?: Logger);
    getWidgetForm(bearer: string, account: string, companyId: string, serviceId?: string, properties?: WidgetFormFieldsAPIProperties): Promise<WidgetFormEntity>;
    protected remoteList(bearer: string, args: Args): Promise<WidgetFormEntity[]>;
    protected remoteGet(bearer: string, args: Args): Promise<WidgetFormEntity>;
    protected remoteCreate(bearer: string, args: Args, item: WidgetFormEntity): Promise<WidgetFormEntity>;
    protected remoteUpdate(bearer: string, args: Args, item: WidgetFormEntity): Promise<WidgetFormEntity>;
    protected remoteDelete(bearer: string, args: Args): Promise<void>;
    protected localList(args: Args): Promise<WidgetFormEntity[]>;
    protected localGet(args: Args): Promise<WidgetFormEntity>;
    protected localBulkSave(args: Args, forms: WidgetFormEntity[]): Promise<void>;
    protected localDelete(args: Args): Promise<void>;
    protected localBulkDelete(items: WidgetFormEntity[]): Promise<void>;
}
export {};
