/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import HttpClient from './index';
import { EventDto } from '../data/Event';
import { EventFields } from "./items/EventFields";
import { CustomStatusDto } from "../data/CustomStatus";
import { EventSearchBodyDto, EventSearchOption, EventSearchPageDto } from "../data/EventSearch";
export declare class EventService extends HttpClient {
    private static URLS;
    static getApiPath(method: 'LIST' | 'POST' | 'GET' | 'DELETE' | 'PUT', query: {
        companyId: string;
        eventId?: string;
    }): string;
    createEvent(bearer: string, account: string, companyId: string, event: EventDto, force: boolean): Promise<EventDto>;
    updateEvent(bearer: string, account: string, companyId: string, event: EventDto, force?: boolean): Promise<EventDto>;
    updateEventStatus(bearer: string, account: string, companyId: string, eventId: string, status: string): Promise<EventDto>;
    updateEventCustomStatus(bearer: string, account: string, companyId: string, eventId: string, customStatus: CustomStatusDto): Promise<EventDto>;
    getExternalAppointments(bearer: string, account: string, userIds: string, start: string, end: string, timeZone?: string): Promise<EventDto[]>;
    countAppointmentConflict(bearer: string, account: string, searchBody: EventSearchBodyDto): Promise<number>;
    deleteAppointmentConflict(bearer: string, account: string, eventId: string): Promise<void>;
    searchAppointments(bearer: string, account: string, searchBody: EventSearchBodyDto, options?: EventSearchOption): Promise<EventSearchPageDto>;
    getICS(bearer: string, icsUrl: string): Promise<any>;
    getAllEvents(bearer: string, account: string, userIds: string, start: string, end: string, showPersonal?: boolean, showDeleted?: boolean, fields?: EventFields[], syncToken?: string): Promise<{
        nextSyncToken?: string;
        items: EventDto[];
    }>;
    getById(bearer: string, account: string, eventId: string, showPersonal?: boolean): Promise<EventDto>;
    getByCompanyAndId(bearer: string, account: string, companyId: string, eventId: string, showPersonal?: boolean): Promise<EventDto>;
    private _prepareFormFields;
    protected filteredDataLog(data: any): any;
}
