/**
 * Copyright 2022 Agendize All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at.
 *
 *      Http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { AxiosInstance, AxiosRequestConfig } from 'axios';
import { AuthenticationService } from './authenticationService';
import { LoggerInterface } from "../utils/logger";
declare module 'axios' {
    interface AxiosResponse<T = any> extends Promise<T> {
    }
}
export default abstract class HttpClient {
    private authenticationService;
    protected logger?: LoggerInterface;
    private bearerCall;
    protected readonly instance: AxiosInstance;
    private axiosLoggerBuilder;
    protected readonly baseUrl: string;
    protected abortControllers: Map<string, AbortController>;
    constructor(baseURL: string, authenticationService: AuthenticationService, logger?: LoggerInterface);
    protected filteredDataLog(data: any): any;
    protected getAxiosConfig(bearer: string, account?: string): AxiosRequestConfig;
    private _initializeRequestInterceptor;
    private isAbortableRequest;
    private _handleRequest;
    private _initializeResponseInterceptor;
    private _handleResponse;
    private _handleError;
    private _handleRefreshToken;
}
